@@ -480,7 +480,7 @@ function get_basis(
     n⃗ = size(𝔄)
     r⃗ = size(𝔄.hosvd.core)
     U = 𝔄.hosvd.U
-    U⊥ = ntuple(d -> Matrix(qr(I - U[d] * U[d]', Val(true)).Q)[:, 1:(n⃗[d] - r⃗[d])], D)
+    U⊥ = ntuple(d -> Matrix(qr(I - U[d] * U[d]', ColumnNorm()).Q)[:, 1:(n⃗[d] - r⃗[d])], D)
     basis = HOSVDBasis(𝔄, U⊥)
     return CachedBasis(basisType, basis)
 end
